@@ -1,7 +1,8 @@
 from os import environ
 
-from .core import Gemini
-from .async_core import GeminiClient
+from .sync_client import Gemini
+from .async_client import GeminiClient
+from .src.module.openrouter.client import OpenRouter
 
 from .src.model.image import GeminiImage
 from .src.model.output import GeminiCandidate, GeminiModelOutput
@@ -9,7 +10,7 @@ from .src.model.parser.base import BaesParser
 from .src.model.parser.custom_parser import ParseMethod1, ParseMethod2
 from .src.model.parser.response_parser import ResponseParser
 
-from .src.misc.constants import Tool
+from .src.misc.constants import URLs, Headers
 from .src.misc.decorator import retry, log_method, time_execution, handle_errors
 from .src.misc.exceptions import PackageError, GeminiAPIError, TimeoutError
 from .src.misc.utils import extract_code, upload_image, max_token, max_sentence
@@ -24,7 +25,7 @@ except ImportError as e:
 
 gemini_api_key = environ.get("GEMINI_COOKIES")
 
-__version__ = "2.2.0"
+__version__ = "2.4.1"
 __author__ = (
     "daniel park <parkminwoo1991@gmail.com>, antonio cheang <teapotv8@proton.me>"
 )
